@@ -382,7 +382,7 @@ show_props (void)
 	g_signal_connect (theme, "changed", G_CALLBACK (theme_changed_cb), xml);
 	theme_changed_cb (theme, xml);
 	
-	gtk_window_set_default_icon_name ("gnome-dev-cdrom");
+	gtk_window_set_default_icon_name ("drive-optical");
 	
 	gvm_settings_hash = g_hash_table_new (g_str_hash, g_str_equal);
 	for (i = 0; i < G_N_ELEMENTS (gvm_settings); i++) {
